# Tools for Agents

This module contains various tools for LLM agents.

```bash
# Tool for getting a list of recent news headlines from enwiki
uv run --env-file .env python3 aieng-agents/aieng/tools/news_events.py
```
